package SAML::SPMetadata::AssertionConsumerService ;

# We bend the variable naming convention in some cases since we want the
# variable name to match the XML attribute name:
## no critic (NamingConventions::Capitalization)

use strict ;
use warnings ;
use autodie ;

# Make this a Moose class
use Moose ;
use namespace::autoclean;

use SAML::SPMetadata::Utility qw/
  get_node_attribute
  get_elements_matching
  get_strings_from_elements
/ ;

has Location => (
  is        => 'rw',
  isa       => 'Str',
  required  => 1,
) ;

has Binding => (
  is        => 'rw',
  isa       => 'Str',
  required  => 1,
) ;

has index => (
  is        => 'rw',
  isa       => 'Int',
  required  => 1,
) ;

# Returns undef if cannot parse.
sub from_node {
    my ($node) = @_ ;

    my $Location = get_node_attribute($node, 'Location') ;
    my $Binding  = get_node_attribute($node, 'Binding') ;
    my $index    = get_node_attribute($node, 'index') ;

    if ($Location && $Binding) {
        my $acs = SAML::SPMetadata::AssertionConsumerService->new(
        'Location' => $Location,
        'Binding'  => $Binding,
        'index'    => $index,
        ) ;

        return $acs ;
    } else {
        return ;
    }
}

# Returns { index => [Binding, Location] }
sub to_hash {
    my $self = shift ;

    my %hash = () ;
    $hash{$self->index()} = [$self->Binding(), $self->Location()] ;

    return \%hash ;
}


sub get_ACS_from_SPSSODescriptor {
    my ($SPSSODescriptor_node) = @_ ;

    # Get all the AssertionConsumerService child elements of
    # $SPSSODescriptor_node.
    my %ACS = () ;
    if ($SPSSODescriptor_node) {
        foreach my $child ($SPSSODescriptor_node->childNodes) {
            if ($child->nodeName() =~ m{AssertionConsumerService}xsm) {
                # Get the Binding and Location attributes of this node.
                if ($child->hasAttribute('Binding') &&
                    $child->hasAttribute('Location')) {
                    my $Binding  = $child->getAttribute('Binding') ;
                    my $Location = $child->getAttribute('Location') ;
                    $ACS{$Binding} = $Location ;
                }
            }
        }
    }

    return %ACS ;
}

1 ;
