package SAML::SPMetadata::ContactPerson ;

# We bend the variable naming convention in some cases since we want the
# variable name to match the XML attribute name:
## no critic (NamingConventions::Capitalization)

# Perl object to represent a ConctactPerson element used in an SP metadata
# XML string.

use strict ;
use warnings ;
use autodie ;

# Make this a Moose class
use Moose ;
use namespace::autoclean;

use Carp ;
use Data::Dumper ;

use SAML::SPMetadata::Utility qw/
  get_node_attribute
  get_elements_matching
  get_strings_from_elements
/ ;

has contactType => (
  is        => 'rw',
  isa       => 'Maybe[Str]',
  required  => 0,
    ) ;

has Company => (
  is        => 'rw',
  isa       => 'Maybe[Str]',
  required  => 0,
    ) ;

has GivenName => (
  is        => 'rw',
  isa       => 'Maybe[Str]',
  required  => 0,
    ) ;

has SurName => (
  is        => 'rw',
  isa       => 'Maybe[Str]',
  required  => 0,
    ) ;

has EmailAddresses => (
  is        => 'rw',
  isa       => 'ArrayRef[Str]',
  required  => 0,
    ) ;

has TelephoneNumbers => (
  is        => 'rw',
  isa       => 'ArrayRef[Str]',
  required  => 0,
    ) ;


sub from_node {
    my ($node) = @_ ;

    my $contactType = get_node_attribute($node, 'contactType') ;

    # ## ### #    # ## ### #    # ## ### #    # ## ### #    # ## ### #
    my $get_single_element_fref = sub {
        my ($element_name) = @_ ;
        my @nodes = get_elements_matching($node, $element_name) ;
        if (scalar(@nodes) > 1) {
            croak "found more than one element for '$element_name'" ;
        }
        my $strings_aref = get_strings_from_elements(\@nodes) ;
        return $strings_aref->[0] ;
    } ;
    # ## ### #    # ## ### #    # ## ### #    # ## ### #    # ## ### #

    my @EmailAddresses   = get_elements_matching($node, 'EmailAddress') ;
    my @TelephoneNumbers = get_elements_matching($node, 'TelephoneNumber') ;

    my $cp = SAML::SPMetadata::ContactPerson->new(
        'contactType'      => $contactType,
        'Company'          => $get_single_element_fref->('Company'),
        'GivenName'        => $get_single_element_fref->('GivenName'),
        'SurName'          => $get_single_element_fref->('SurName'),
        'EmailAddresses'   => get_strings_from_elements(\@EmailAddresses),
        'TelephoneNumbers' => get_strings_from_elements(\@TelephoneNumbers),
        ) ;

    return $cp ;
}

sub to_hash {
    my $self = shift ;

    my %hash = () ;
    $hash{'contactType'} = $self->contactType() ;

    $hash{'Company'}     = $self->Company() ;
    $hash{'GivenName'}   = $self->GivenName() ;
    $hash{'SurName'}     = $self->SurName() ;

    $hash{'contactType'} = $self->contactType() ;

    $hash{'EmailAddresses'}   = $self->EmailAddresses() ;
    $hash{'TelephoneNumbers'} = $self->TelephoneNumbers() ;

    return \%hash ;
}

1;
