package SAML::SPMetadata::Utility ;

use strict ;
use warnings ;
use autodie ;

use base qw( Exporter ) ;
our @EXPORT_OK = qw
    (
     get_node_attribute
     get_elements_matching
     get_strings_from_elements
     trim
    ) ;

use Carp ;

# Returns nothing if there is no such attribute.
sub get_node_attribute {
    my ($node, $attribute_name) = @_ ;

    my @attributes = $node->attributes() ;
    foreach my $attribute (@attributes) {
        my $name = $attribute->name() ;
        if ($name eq $attribute_name) {
            return $attribute->getValue() ;
        }
    }

    # Return undef (we return "nothing" to avoid perlcritic yelling at
    # us).
    return ;
}

# Get all the elements (at any level) matching $element_name.
sub get_elements_matching {
    my ($node, $element_name) = @_ ;
    return $node->findnodes(qq{.//*[local-name()='$element_name']}) ;
}

# Given an array reference of elements, get the content of each and
# return as an array reference of contents.
sub get_strings_from_elements {
    my ($elemets_aref) = @_ ;

    my @elements = @{ $elemets_aref } ;
    my @contents = () ;
    foreach my $element (@elements) {
        my $content = trim($element->textContent()) ;
        push (@contents, $content) ;
    }

    return \@contents ;
}

sub trim {
    my ($s) = @_ ;

    if (!defined($s)) { return $s }

    $s =~ s{^\s*}{}xs ;  ## no critic (RequireLineBoundaryMatching) ;
    $s =~ s{\s*$}{}xs ;  ## no critic (RequireLineBoundaryMatching) ;

    return $s ;
}

1 ;
